==> vue-pager-2.23.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import MobileFirstTemplate from "./mobile-first.js";
import "@opentinyvue/vue-theme/pager/index.css";
var template = function template2(mode) {
  var _process$env;
  var tinyMode = typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  if ("pc" === (tinyMode || mode)) {
    return PcTemplate;
  }
  if ("mobile-first" === (tinyMode || mode)) {
    return MobileFirstTemplate;
  }
  return PcTemplate;
};
var pagerProps = _extends({}, $props, {
  accurateJumper: {
    type: Boolean,
    default: function _default() {
      return true;
    }
  },
  appendToBody: {
    type: Boolean,
    default: function _default2() {
      return true;
    }
  },
  currentPage: {
    type: Number,
    default: function _default3() {
      return 1;
    }
  },
  disabled: {
    type: Boolean,
    default: function _default4() {
      return false;
    }
  },
  hideOnSinglePage: Boolean,
  isBeforePageChange: Boolean,
  layout: String,
  mode: String,
  nextText: String,
  pageCount: Number,
  pageSize: {
    type: Number,
    default: function _default5() {
      return 10;
    }
  },
  pageSizeText: {
    type: String
  },
  pageSizes: {
    type: Array,
    default: function _default6() {
      return [10, 20, 30, 40, 50, 100];
    }
  },
  pagerCount: {
    type: Number,
    validator: function validator(value) {
      return (value | 0) === value && value > 2 && value < 22 && value % 2 === 1;
    },
    default: function _default7() {
      return 7;
    }
  },
  popperAppendToBody: {
    type: Boolean,
    default: function _default8() {
      return true;
    }
  },
  showTotalLoading: {
    type: Boolean,
    default: function _default9() {
      return false;
    }
  },
  customTotal: {
    type: [Boolean, String],
    default: function _default10() {
      return false;
    }
  },
  popperClass: String,
  prevText: String,
  total: Number,
  size: {
    type: String,
    default: "",
    validator: function validator2(value) {
      return ["mini", ""].includes(value);
    }
  },
  align: {
    type: String,
    validator: function validator3(value) {
      return ["left", "center", "right"].includes(value);
    }
  },
  totalFixedLeft: {
    type: Boolean,
    default: void 0
  },
  // tiny新增
  changeCompat: {
    type: Boolean,
    default: false
  }
});
var Pager = defineComponent({
  name: $prefix + "Pager",
  props: pagerProps,
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "2.23.0";
Pager.install = function(Vue) {
  Vue.component(Pager.name, Pager);
};
Pager.version = version;
export {
  Pager as default
};

==> vue-pager-2.24.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $props, $setup, $prefix } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import MobileFirstTemplate from "./mobile-first.js";
import "@opentinyvue/vue-theme/pager/index.css";
var template = function template2(mode) {
  var _process$env;
  var tinyMode = typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  if ("pc" === (tinyMode || mode)) {
    return PcTemplate;
  }
  if ("mobile-first" === (tinyMode || mode)) {
    return MobileFirstTemplate;
  }
  return PcTemplate;
};
var pagerProps = _extends({}, $props, {
  accurateJumper: {
    type: Boolean,
    default: function _default() {
      return true;
    }
  },
  appendToBody: {
    type: Boolean,
    default: function _default2() {
      return true;
    }
  },
  currentPage: {
    type: Number,
    default: function _default3() {
      return 1;
    }
  },
  disabled: {
    type: Boolean,
    default: function _default4() {
      return false;
    }
  },
  hideOnSinglePage: Boolean,
  isBeforePageChange: Boolean,
  layout: String,
  mode: String,
  nextText: String,
  pageCount: Number,
  pageSize: {
    type: Number,
    default: function _default5() {
      return 10;
    }
  },
  pageSizeText: {
    type: String
  },
  pageSizes: {
    type: Array,
    default: function _default6() {
      return [10, 20, 30, 40, 50, 100];
    }
  },
  pagerCount: {
    type: Number,
    validator: function validator(value) {
      return (value | 0) === value && value > 2 && value < 22 && value % 2 === 1;
    },
    default: function _default7() {
      return 7;
    }
  },
  popperAppendToBody: {
    type: Boolean,
    default: function _default8() {
      return true;
    }
  },
  showTotalLoading: {
    type: Boolean,
    default: function _default9() {
      return false;
    }
  },
  customTotal: {
    type: [Boolean, String],
    default: function _default10() {
      return false;
    }
  },
  popperClass: String,
  prevText: String,
  total: Number,
  size: {
    type: String,
    default: "",
    validator: function validator2(value) {
      return ["mini", ""].includes(value);
    }
  },
  align: {
    type: String,
    validator: function validator3(value) {
      return ["left", "center", "right"].includes(value);
    }
  },
  totalFixedLeft: {
    type: Boolean,
    default: void 0
  },
  // tiny新增
  changeCompat: {
    type: Boolean,
    default: false
  }
});
var Pager = defineComponent({
  name: $prefix + "Pager",
  props: pagerProps,
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "2.undefined";
Pager.install = function(Vue) {
  Vue.component(Pager.name, Pager);
};
Pager.version = version;
export {
  Pager as default
};
